'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var _babelCore = require('babel-core');

const defaults = {
  include: '**/*.{js,jsx,babel.js}',
  replaceExt: /\.(jsx|babel\.js)$/,
  sourceMaps: true
};

exports['default'] = function (options) {
  options = Object.assign({}, defaults, options);

  // remove special plugin-only options
  const include = options.include;
  delete options.include;
  const replaceExt = options.replaceExt;
  delete options.replaceExt;

  return function exhibitBabel(_ref) {
    var matches = _ref.matches;
    var file = _ref.file;
    var contents = _ref.contents;
    var util = _ref.util;

    // pass non-JS files straight through
    if (!matches(include)) return contents;

    // replace extension for outgoing filename (if it's jsx or whatever)
    const jsFilename = replaceExt ? file.replace(replaceExt, '.js') : file;

    // compile the contents
    const source = contents.toString();
    var result = undefined;
    try {
      result = (0, _babelCore.transform)(source, options);
    } catch (error) {
      // todo: remove the "(line:column)" from end of message
      throw new util.SourceError({
        file: file,
        message: error.message,
        contents: source,
        line: error.loc ? error.loc.line : null,
        column: error.loc ? error.loc.column : null
      });
    }

    if (options.sourceMaps) {
      const comment = util.convertSourceMap.fromObject(result.map).setProperty('sources', [file]).toComment();

      return { [jsFilename]: `${ result.code }\n${ comment }` };
    }

    return { [jsFilename]: result.code };
  };
};

module.exports = exports['default'];
//# sourceMappingURL=index.js.map